@@ -214,8 +214,7 @@ setAs("SummarizedExperiment", "RangedSummarizedExperiment",
 ### Getters and setters.
 ###
 
-setGeneric("rowRanges", function(x, ...) standardGeneric("rowRanges"))
-
+### The rowRanges() generic is defined in the DelayedArray package.
 setMethod("rowRanges", "RangedSummarizedExperiment",
     function(x, ...) x@rowRanges
 )
@@ -280,6 +279,9 @@ setReplaceMethod("dimnames", c("RangedSummarizedExperiment", "list"),
 ### Subsetting.
 ###
 
+.DollarNames.RangedSummarizedExperiment <-
+    .DollarNames.SummarizedExperiment
+
 setMethod("subset", "RangedSummarizedExperiment",
     function(x, subset, select, ...)
 {
@@ -439,7 +441,8 @@ setMethod("is.unsorted", "RangedSummarizedExperiment",
 })
 
 setMethod("order", "RangedSummarizedExperiment",
-    function(..., na.last=TRUE, decreasing=FALSE, method=c("shell", "radix"))
+    function(..., na.last=TRUE, decreasing=FALSE,
+             method=c("auto", "shell", "radix"))
 {
     args <- lapply(list(...), rowRanges)
     do.call("order", c(args, list(na.last=na.last,
@@ -462,9 +465,9 @@ setMethod("sort", "RangedSummarizedExperiment",
     if (!is(x_rowRanges, "GenomicRanges"))
         stop("sort() is not yet supported when 'rowRanges(x)' is a ",
              class(x_rowRanges), " object")
-    oo <- GenomicRanges:::.order_GenomicRanges(x_rowRanges,
-                                               decreasing = decreasing,
-                                               ignore.strand = ignore.strand)
+    oo <- GenomicRanges:::order_GenomicRanges(x_rowRanges,
+                                              decreasing = decreasing,
+                                              ignore.strand = ignore.strand)
     x[oo]
 })
 
@@ -477,13 +480,17 @@ setMethod("seqinfo", "RangedSummarizedExperiment",
 })
 
 setReplaceMethod("seqinfo", "RangedSummarizedExperiment",
-    function (x, new2old = NULL, force = FALSE, value)
+    function (x, new2old= NULL, force=FALSE,
+              pruning.mode=c("error", "coarse", "fine", "tidy"),
+              value)
 {
     if (!is(value, "Seqinfo")) 
         stop("the supplied 'seqinfo' must be a Seqinfo object")
     dangling_seqlevels <-
-        GenomeInfoDb:::getDanglingSeqlevels(x@rowRanges, new2old = new2old,
-                                            force = force, seqlevels(value))
+        GenomeInfoDb:::getDanglingSeqlevels(x@rowRanges, new2old=new2old,
+                                            force=force,
+                                            pruning.mode=pruning.mode,
+                                            seqlevels(value))
     if (length(dangling_seqlevels) != 0L) 
         x <- x[!(seqnames(x) %in% dangling_seqlevels)]
     x@rowRanges <-
